@@ -23,8 +23,8 @@ import sys
 from PyQt5.QtGui import QFontDatabase
 from PyQt5.QtWidgets import QApplication
 
-from obserware.commons import resources
-from obserware.screens.mainwind.operations import MainWind
+from obserware.sources.commons import resources
+from obserware.sources.screens.mainwind.operations import MainWind
 
 
 def populate_font_database():
@@ -32,6 +32,7 @@ def populate_font_database():
         ":/fontrsrc/fonts/intr-bold.ttf",
         ":/fontrsrc/fonts/intr-rlar.ttf",
         ":/fontrsrc/fonts/mono-rlar.ttf",
+        ":/fontrsrc/fonts/fnas-icon.ttf",
     ]
     for indx in fontlist:
         QFontDatabase.addApplicationFont(indx)
